<?php
function libre_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'libre_custom_header_args', array(
		'default-image'          => '',
		'default-text-color'     => '404040',
		'width'                  => 1088,
		'height'                 => 300,
		'flex-height'            => true,
		'wp-head-callback'       => 'libre_header_style',
		'admin-head-callback'    => 'libre_admin_header_style',
		'admin-preview-callback' => 'libre_admin_header_image',
	) ) );
}
add_action( 'after_setup_theme', 'libre_custom_header_setup' );

function libre_header_style() {
    $header_text_color = get_header_textcolor();

    $general_font = get_theme_mod( 'general_font' );
    $heading_font = get_theme_mod( 'heading_font' );

    $menu_font = get_theme_mod( 'menu_font' );
    $content_font = get_theme_mod( 'content_font' );
    $button_font = get_theme_mod( 'button_font' );

    $button_bg = get_theme_mod( 'button_bg' );
    $button_purchase_bg = get_theme_mod( 'button_purchase_bg' );

    $menu_color = get_theme_mod( 'menu_color' );
    $hide_titles = get_theme_mod( 'hide_titles' );

    // If no custom options for text are set, let's bail
    // get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value.
    /*if ( HEADER_TEXTCOLOR == $header_text_color ) {
    return;
    }*/

// If we get this far, we have custom styles. Let's do this.
?>
<style type="text/css">
    <?php
        // Has the text been hidden?
        if ( 'blank' == $header_text_color ) :
    ?>
    .site-branding {
        display: none;
    }
    .site-title,
    .site-description {
        position: absolute;
        clip: rect(1px, 1px, 1px, 1px);
    }
    #site-navigation {
        width: 100%;
    }
    .main-navigation {
        text-align: left;
    }
    <?php
        // If the user has set a custom color for the text use that.
        else :
    ?>
    .site-title a,
    .site-description, .hello {
        color: #<?php echo esc_attr( $header_text_color ); ?>;
    }

    <?php endif; ?>
    <?php if ( !empty($general_font) || $general_font != 'inherit' ) : ?>
        body, button, input, select, textarea {
            font-family: <?php echo $general_font; ?>
        }
    <?php endif; ?>
    <?php  if ( !empty($heading_font) && $heading_font != 'inherit' ) : ?>
        h1, h2, h3, h4, h5, h1 a, h2 a{
            font-family: <?php echo $heading_font; ?>
        }
    <?php endif; ?>
    <?php  if (  !empty($menu_font) && $menu_font != 'inherit' ) : ?>
        .menu a{
            font-family: <?php echo $menu_font; ?>
        }
    <?php endif; ?>

    <?php  if (  !empty($hide_titles) && $hide_titles == 1 ) : ?>
    h1.entry-title {
        display: none;
    }
    <?php endif; ?>

    <?php  if ( !empty($content_font) && $content_font != 'inherit' ) : ?>
    .entry-content, .entry-content table, .entry-content ul, .entry-content p{
        font-family: <?php echo $content_font; ?>
    }
    <?php endif; ?>

    <?php $button_style = ''; ?>

    <?php  if ( !empty($button_font) && $button_font != 'inherit' ) : ?>
        <?php $button_style = 'font-family: ' . $button_font . ';' ;  ?>
    <?php endif; ?>

    <?php  if ( !empty($button_bg) && $button_bg != '#4e8619' ) : ?>
        <?php $button_style .= 'background-color: ' . $button_bg . ' !important; ' ;  ?>
        <?php $button_style .= 'border-bottom-color: ' . $button_bg . ' !important; ' ;  ?>
    <?php endif; ?>

    <?php  if ( !empty($button_style) ) : ?>
        a.btn, input[type='submit'], input[type='button'], button {
            <?php echo $button_style; ?>
        }
    <?php endif; ?>

    <?php  if ( !empty($button_purchase_bg) && $button_purchase_bg != 'inherit' ) : ?>
        input[type='submit']#pay-now {
            background-color: <?php echo $button_purchase_bg; ?> !important;
            border-bottom-color: <?php echo $button_purchase_bg; ?> !important;
        }
    <?php endif; ?>
    <?php  if ( get_theme_mod( 'remove_cart_image' ) == true ) : ?>
    input[type='submit']#pay-now, input[type='submit'].cart  {
        background-image: none !important;
        padding-right: 10px;
    }
    <?php endif; ?>

    <?php if ( !empty($menu_color) || $menu_color != 'inherit' ) : ?>
    #site-navigation a {
        color: <?php echo $menu_color; ?>
    }
    <?php endif; ?>

    <?php  if ( get_theme_mod( 'full_header' ) !== false ) : ?>
    #page {
        margin-top: 0;
    }
    #page .custom-header {
        width: 100vw;
        position: relative;z
        left: 50%;
        right: 50%;
        margin-left: -50vw;
        margin-right: -50vw;
        max-width: none;
    }
    <?php endif; ?>

</style>
<?php
}

function ppy_typography_google_fonts() {
    $all_google_fonts = array_keys( ppy_get_google_fonts() );

    $general_font = get_theme_mod( 'general_font' );
    $heading_font = get_theme_mod( 'heading_font' );

    $menu_font = get_theme_mod( 'menu_font' );
    $content_font = get_theme_mod( 'content_font' );

    // Get the font face for each option and put it in an array
    $selected_fonts = array(
        $general_font,
        $heading_font,
        $menu_font,
        $content_font
    );
    // Remove any duplicates in the list
    $selected_fonts = array_unique($selected_fonts);
    // Check each of the unique fonts against the defined Google fonts
    // If it is a Google font, go ahead and call the function to enqueue it
    foreach ( $selected_fonts as $font ) {
        if ( in_array( $font, $all_google_fonts ) ) {
            ppy_typography_enqueue_google_font($font);
        }
    }
}

add_action( 'wp_enqueue_scripts', 'ppy_typography_google_fonts' );


/**
 * Enqueues the Google $font that is passed
 */

function ppy_typography_enqueue_google_font($font) {
    $font = explode(',', $font);
    $font = $font[0];
    // Certain Google fonts need slight tweaks in order to load properly
    // Like our friend "Raleway"
    if ( $font == 'Raleway' )
        $font = 'Raleway:100';
    $font = str_replace(" ", "+", $font);
    wp_enqueue_style( "options_typography_$font", "http://fonts.googleapis.com/css?family=$font", false, null, 'all' );
}

function libre_admin_header_image() {
?>
    <div id="headimg">
        <h1 class="displaying-header-text">
            <a id="name" style="<?php echo esc_attr( 'color: #' . get_header_textcolor() ); ?>" onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a>
        </h1>
        <div class="displaying-header-text" id="desc" style="<?php echo esc_attr( 'color: #' . get_header_textcolor() ); ?>"><?php bloginfo( 'description' ); ?></div>
		<?php if ( get_header_image() ) : ?>
            <img src="<?php header_image(); ?>" alt="">
		<?php endif; ?>
    </div>
<?php
}