<?php
/**
 * Libre Theme Customizer
 *
 * @package Libre
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ppy_customize_register( $wp_customize ) {
    $fonts = array(
        'inherit' =>'Default',
        'Arial, Helvetica, sans-serif' => 'Arial',
        '"Courier New", Courier, monospace' => 'Courier New',
        'Futura, "Century Gothic", AppleGothic, sans-serif' => 'Futura',
        'Georgia, Times, "Times New Roman", serif' => 'Georgia',
        'Georgia, serif' => 'Georgia',
        'Palatino, "Palatino Linotype", Georgia, Times, "Times New Roman", serif' => 'Palatino',
        'Tahoma, Geneva, Verdana, sans-serif' => 'Tahoma',
        '"Times New Roman", Times, Georgia, serif' => 'Times New Roman',
        '"Trebuchet MS", Tahoma, Arial, sans-serif' => 'Trebuchet',
        'Verdana, Geneva, Tahoma, sans-serif' => 'Verdana',

    );
    $google_fonts = ppy_get_google_fonts(30);
    $fonts = array_merge( $fonts, $google_fonts );

    $wp_customize->add_setting( 'general_font' , array(
        'default'     => "inherit",
        'transport'   => 'refresh',
    ) );

    $wp_customize->add_setting( 'heading_font' , array(
        'default'     => "inherit",
        'transport'   => 'refresh',
    ) );
    $wp_customize->add_setting( 'menu_font' , array(
        'default'     => "inherit",
        'transport'   => 'refresh',
    ) );
    $wp_customize->add_setting( 'content_font' , array(
        'default'     => "inherit",
        'transport'   => 'refresh',
    ) );
    $wp_customize->add_setting( 'button_font' , array(
        'default'     => "inherit",
        'transport'   => 'refresh',
    ) );

    $wp_customize->add_section( 'ppy_fonts' , array(
        'title'      => __( 'Fonts', 'ppy' ),
        'priority'   => 30,
    ) );

    $wp_customize->add_control( 'general_font', array(
        'label' => __( 'General Font' ),
        'type' => 'select',
        'section' => 'ppy_fonts',
        'choices' => $fonts
    ) );

    $wp_customize->add_control( 'heading_font', array(
        'label' => __( 'Heading Font', 'libre' ),
        'type' => 'select',
        'section' => 'ppy_fonts',
        'choices' => $fonts
    ) );
    $wp_customize->add_control( 'menu_font', array(
        'label' => __( 'Menu Font', 'libre' ),
        'type' => 'select',
        'section' => 'ppy_fonts',
        'choices' => $fonts
    ) );
    $wp_customize->add_control( 'content_font', array(
        'label' => __( 'Content Font', 'libre' ),
        'type' => 'select',
        'section' => 'ppy_fonts',
        'choices' => $fonts
    ) );
    $wp_customize->add_control( 'button_font', array(
        'label' => __( 'Button Font', 'libre' ),
        'type' => 'select',
        'section' => 'ppy_fonts',
        'choices' => $fonts
    ) );
}

function ppy_customize_colors( $wp_customize ) {
    $wp_customize->add_setting( 'menu_color' , array(
        'default'     => 'inherit',
        'transport'   => 'refresh',
    ) );

    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'menu_color',
            array(
                'label'      => __( 'Menu color', 'libre' ),
                'section'    => 'colors',
                'settings'   => 'menu_color',
            ) )
    );

}

function ppy_customize_titles( $wp_customize ) {
    $wp_customize->add_setting( 'hide_titles' , array(
        'default'     => 0,
        'transport'   => 'refresh',
        'capability' => 'edit_theme_options'
    ) );

    $wp_customize->add_control( 'hide_titles', array(
        'label'      => __( 'Hide all titles?', 'documentation' ),
        'section'    => 'title_tagline',
        'settings'   => 'hide_titles',
        'type'       => 'checkbox',
        'std'         => '1'
    ) );
}

function ppy_customize_button( $wp_customize ) {

    $wp_customize->add_setting( 'button_bg' , array(
        'default'     => "#4e8619",
        'transport'   => 'refresh',
    ) );

    $wp_customize->add_setting( 'button_purchase_bg' , array(
        'default'     => "#4e8619",
        'transport'   => 'refresh',
    ) );
    $wp_customize->add_setting( 'remove_cart_image' , array(
        'default'     => "",
        'transport'   => 'refresh',
    ) );
    $wp_customize->add_setting( 'button_purchase_text' , array(
        'default'     => "",
        'transport'   => 'refresh',
    ) );

    $wp_customize->add_section( 'ppy_buttons' , array(
        'title'      => __( 'Buttons', 'ppy' ),
        'priority'   => 30,
    ) );

    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'button_bg',
            array(
                'label'      => __( 'Button Background', 'libre' ),
                'section'    => 'ppy_buttons',
                'settings'   => 'button_bg',
            ) )
    );
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'button_purchase_bg',
            array(
                'label'      => __( 'Purchase Button Background', 'libre' ),
                'section'    => 'ppy_buttons',
                'settings'   => 'button_purchase_bg',
            ) )
    );

    $wp_customize->add_control( 'remove_cart_image', array(
        'label' => __( 'Remove cart image?', 'libre' ),
        'type' => 'checkbox',
        'section' => 'ppy_buttons',
    ) );

    $wp_customize->add_control( 'button_purchase_text', array(
        'label' => __( 'Purchase Text', 'libre' ),
        'type' => 'text',
        'section' => 'ppy_buttons',
    ) );

}

function ppy_customize_header( $wp_customize ) {
	$wp_customize->add_setting( 'full_header' , array(
		'default'     => true,
		'transport'   => 'refresh',
	) );
	$wp_customize->add_control( 'full_header', array(
		'label' => __( 'Full Width Header?', 'libre' ),
		'type' => 'checkbox',
		'section' => 'header_image',
	) );
}
add_action( 'customize_register', 'ppy_customize_register' );
add_action( 'customize_register', 'ppy_customize_button' );
add_action( 'customize_register', 'ppy_customize_colors' );
add_action( 'customize_register', 'ppy_customize_titles' );
add_action( 'customize_register', 'ppy_customize_header' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ppy_customize_preview_js() {
    wp_enqueue_script( 'ppy_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'ppy_customize_preview_js' );

function ppy_get_google_fonts( $amount = 30 ) {

    if ( false === ( $fonts = get_transient( 'ppy_google_fonts' ) ) ) {
        $googleApi = 'https://www.googleapis.com/webfonts/v1/webfonts?sort=popularity&key=AIzaSyCD6NStkHTI5FxX1EMI3EIkyZBg6kcVsLQ';
        $fontContent = wp_remote_get( $googleApi, array( 'sslverify'   => false) );

        if ( !is_wp_error( $fontContent ) ) {
            $content = json_decode( $fontContent['body'] );

            foreach (  $content->items as $k => $v ) {
                $fonts['"' .$v->family . '",' . $v->category] = $v->family;
            }

            set_transient( 'ppy_google_fonts', $fonts, 7 * DAY_IN_SECONDS );
        }
    }
    if($amount == 'all') {
        return $fonts;
    } elseif ( is_array( $fonts ) ) {
        return array_slice( $fonts, 0, $amount );
    } else {
        delete_transient( 'ppy_google_fonts' );
        return array();
    }
}
